@@ -69,6 +69,7 @@ using gl::glBindProgramPipeline;
 using gl::glBindRenderbufferEXT;
 using gl::glBindSampler;
 using gl::glBindSamplers;
+using gl::glBindShadingRateImageNV;
 using gl::glBindTexGenParameterEXT;
 using gl::glBindTextureEXT;
 using gl::glBindTextureUnit;
@@ -118,6 +119,7 @@ using gl::glBlendParameteriNV;
 using gl::glBlitFramebufferEXT;
 using gl::glBlitNamedFramebuffer;
 using gl::glBufferAddressRangeNV;
+using gl::glBufferAttachMemoryNV;
 using gl::glBufferDataARB;
 using gl::glBufferPageCommitmentARB;
 using gl::glBufferParameteriAPPLE;
@@ -384,6 +386,8 @@ using gl::glDrawElementsInstancedBaseVertex;
 using gl::glDrawElementsInstancedBaseVertexBaseInstance;
 using gl::glDrawElementsInstancedEXT;
 using gl::glDrawMeshArraysSUN;
+using gl::glDrawMeshTasksIndirectNV;
+using gl::glDrawMeshTasksNV;
 using gl::glDrawRangeElementArrayAPPLE;
 using gl::glDrawRangeElementArrayATI;
 using gl::glDrawRangeElementsBaseVertex;
@@ -395,6 +399,8 @@ using gl::glDrawTransformFeedbackNV;
 using gl::glDrawTransformFeedbackStream;
 using gl::glDrawTransformFeedbackStreamInstanced;
 using gl::glDrawVkImageNV;
+using gl::glEGLImageTargetTexStorageEXT;
+using gl::glEGLImageTargetTextureStorageEXT;
 using gl::glEdgeFlagFormatNV;
 using gl::glEdgeFlagPointerEXT;
 using gl::glEdgeFlagPointerListIBM;
@@ -637,6 +643,7 @@ using gl::glGetMapParameterfvNV;
 using gl::glGetMapParameterivNV;
 using gl::glGetMapxvOES;
 using gl::glGetMaterialxOES;
+using gl::glGetMemoryObjectDetachedResourcesuivNV;
 using gl::glGetMemoryObjectParameterivEXT;
 using gl::glGetMinmax;
 using gl::glGetMinmaxEXT;
@@ -773,6 +780,8 @@ using gl::glGetSeparableFilter;
 using gl::glGetSeparableFilterEXT;
 using gl::glGetShaderPrecisionFormat;
 using gl::glGetShaderSourceARB;
+using gl::glGetShadingRateImagePaletteNV;
+using gl::glGetShadingRateSampleLocationivNV;
 using gl::glGetSharpenTexFuncSGIS;
 using gl::glGetStageIndexNV;
 using gl::glGetSubroutineIndex;
@@ -1097,6 +1106,8 @@ using gl::glMultiDrawElementsIndirectBindlessCountNV;
 using gl::glMultiDrawElementsIndirectBindlessNV;
 using gl::glMultiDrawElementsIndirectCount;
 using gl::glMultiDrawElementsIndirectCountARB;
+using gl::glMultiDrawMeshTasksIndirectCountNV;
+using gl::glMultiDrawMeshTasksIndirectNV;
 using gl::glMultiDrawRangeElementArrayAPPLE;
 using gl::glMultiModeDrawArraysIBM;
 using gl::glMultiModeDrawElementsIBM;
@@ -1200,6 +1211,7 @@ using gl::glMulticastGetQueryObjectivNV;
 using gl::glMulticastGetQueryObjectui64vNV;
 using gl::glMulticastGetQueryObjectuivNV;
 using gl::glMulticastWaitSyncNV;
+using gl::glNamedBufferAttachMemoryNV;
 using gl::glNamedBufferData;
 using gl::glNamedBufferDataEXT;
 using gl::glNamedBufferPageCommitmentARB;
@@ -1244,6 +1256,7 @@ using gl::glNamedProgramStringEXT;
 using gl::glNamedRenderbufferStorage;
 using gl::glNamedRenderbufferStorageEXT;
 using gl::glNamedRenderbufferStorageMultisample;
+using gl::glNamedRenderbufferStorageMultisampleAdvancedAMD;
 using gl::glNamedRenderbufferStorageMultisampleCoverageEXT;
 using gl::glNamedRenderbufferStorageMultisampleEXT;
 using gl::glNamedStringARB;
@@ -1553,6 +1566,7 @@ using gl::glReleaseKeyedMutexWin32EXT;
 using gl::glReleaseShaderCompiler;
 using gl::glRenderGpuMaskNV;
 using gl::glRenderbufferStorageEXT;
+using gl::glRenderbufferStorageMultisampleAdvancedAMD;
 using gl::glRenderbufferStorageMultisampleCoverageNV;
 using gl::glRenderbufferStorageMultisampleEXT;
 using gl::glReplacementCodePointerSUN;
@@ -1581,6 +1595,7 @@ using gl::glReplacementCodeusvSUN;
 using gl::glRequestResidentProgramsNV;
 using gl::glResetHistogram;
 using gl::glResetHistogramEXT;
+using gl::glResetMemoryObjectParameterNV;
 using gl::glResetMinmax;
 using gl::glResetMinmaxEXT;
 using gl::glResizeBuffersMESA;
@@ -1604,6 +1619,8 @@ using gl::glSamplerParameteri;
 using gl::glSamplerParameteriv;
 using gl::glScalexOES;
 using gl::glScissorArrayv;
+using gl::glScissorExclusiveArrayvNV;
+using gl::glScissorExclusiveNV;
 using gl::glScissorIndexed;
 using gl::glScissorIndexedv;
 using gl::glSecondaryColor3bEXT;
@@ -1645,6 +1662,10 @@ using gl::glShaderOp2EXT;
 using gl::glShaderOp3EXT;
 using gl::glShaderSourceARB;
 using gl::glShaderStorageBlockBinding;
+using gl::glShadingRateImageBarrierNV;
+using gl::glShadingRateImagePaletteNV;
+using gl::glShadingRateSampleOrderCustomNV;
+using gl::glShadingRateSampleOrderNV;
 using gl::glSharpenTexFuncSGIS;
 using gl::glSignalSemaphoreEXT;
 using gl::glSignalVkFenceNV;
@@ -1692,6 +1713,7 @@ using gl::glTessellationModeAMD;
 using gl::glTestFenceAPPLE;
 using gl::glTestFenceNV;
 using gl::glTestObjectAPPLE;
+using gl::glTexAttachMemoryNV;
 using gl::glTexBufferARB;
 using gl::glTexBufferEXT;
 using gl::glTexBufferRange;
@@ -1779,6 +1801,7 @@ using gl::glTexSubImage1DEXT;
 using gl::glTexSubImage2DEXT;
 using gl::glTexSubImage3DEXT;
 using gl::glTexSubImage4DSGIS;
+using gl::glTextureAttachMemoryNV;
 using gl::glTextureBarrier;
 using gl::glTextureBarrierNV;
 using gl::glTextureBuffer;
@@ -1944,6 +1967,7 @@ using gl::glVDPAUIsSurfaceNV;
 using gl::glVDPAUMapSurfacesNV;
 using gl::glVDPAURegisterOutputSurfaceNV;
 using gl::glVDPAURegisterVideoSurfaceNV;
+using gl::glVDPAURegisterVideoSurfaceWithPictureStructureNV;
 using gl::glVDPAUSurfaceAccessNV;
 using gl::glVDPAUUnmapSurfacesNV;
 using gl::glVDPAUUnregisterSurfaceNV;
