@@ -63,6 +63,7 @@ using gl::glBindProgramARB;
 using gl::glBindProgramNV;
 using gl::glBindRenderbufferEXT;
 using gl::glBindSamplers;
+using gl::glBindShadingRateImageNV;
 using gl::glBindTexGenParameterEXT;
 using gl::glBindTextureEXT;
 using gl::glBindTextureUnit;
@@ -106,6 +107,7 @@ using gl::glBlendParameteriNV;
 using gl::glBlitFramebufferEXT;
 using gl::glBlitNamedFramebuffer;
 using gl::glBufferAddressRangeNV;
+using gl::glBufferAttachMemoryNV;
 using gl::glBufferDataARB;
 using gl::glBufferPageCommitmentARB;
 using gl::glBufferParameteriAPPLE;
@@ -343,12 +345,16 @@ using gl::glDrawElementArrayATI;
 using gl::glDrawElementsInstancedARB;
 using gl::glDrawElementsInstancedEXT;
 using gl::glDrawMeshArraysSUN;
+using gl::glDrawMeshTasksIndirectNV;
+using gl::glDrawMeshTasksNV;
 using gl::glDrawRangeElementArrayAPPLE;
 using gl::glDrawRangeElementArrayATI;
 using gl::glDrawRangeElementsEXT;
 using gl::glDrawTextureNV;
 using gl::glDrawTransformFeedbackNV;
 using gl::glDrawVkImageNV;
+using gl::glEGLImageTargetTexStorageEXT;
+using gl::glEGLImageTargetTextureStorageEXT;
 using gl::glEdgeFlagFormatNV;
 using gl::glEdgeFlagPointerEXT;
 using gl::glEdgeFlagPointerListIBM;
@@ -570,6 +576,7 @@ using gl::glGetMapParameterfvNV;
 using gl::glGetMapParameterivNV;
 using gl::glGetMapxvOES;
 using gl::glGetMaterialxOES;
+using gl::glGetMemoryObjectDetachedResourcesuivNV;
 using gl::glGetMemoryObjectParameterivEXT;
 using gl::glGetMinmax;
 using gl::glGetMinmaxEXT;
@@ -685,6 +692,8 @@ using gl::glGetSemaphoreParameterui64vEXT;
 using gl::glGetSeparableFilter;
 using gl::glGetSeparableFilterEXT;
 using gl::glGetShaderSourceARB;
+using gl::glGetShadingRateImagePaletteNV;
+using gl::glGetShadingRateSampleLocationivNV;
 using gl::glGetSharpenTexFuncSGIS;
 using gl::glGetStageIndexNV;
 using gl::glGetTexBumpParameterfvATI;
@@ -988,6 +997,8 @@ using gl::glMultiDrawElementsIndirectBindlessCountNV;
 using gl::glMultiDrawElementsIndirectBindlessNV;
 using gl::glMultiDrawElementsIndirectCount;
 using gl::glMultiDrawElementsIndirectCountARB;
+using gl::glMultiDrawMeshTasksIndirectCountNV;
+using gl::glMultiDrawMeshTasksIndirectNV;
 using gl::glMultiDrawRangeElementArrayAPPLE;
 using gl::glMultiModeDrawArraysIBM;
 using gl::glMultiModeDrawElementsIBM;
@@ -1083,6 +1094,7 @@ using gl::glMulticastGetQueryObjectivNV;
 using gl::glMulticastGetQueryObjectui64vNV;
 using gl::glMulticastGetQueryObjectuivNV;
 using gl::glMulticastWaitSyncNV;
+using gl::glNamedBufferAttachMemoryNV;
 using gl::glNamedBufferData;
 using gl::glNamedBufferDataEXT;
 using gl::glNamedBufferPageCommitmentARB;
@@ -1127,6 +1139,7 @@ using gl::glNamedProgramStringEXT;
 using gl::glNamedRenderbufferStorage;
 using gl::glNamedRenderbufferStorageEXT;
 using gl::glNamedRenderbufferStorageMultisample;
+using gl::glNamedRenderbufferStorageMultisampleAdvancedAMD;
 using gl::glNamedRenderbufferStorageMultisampleCoverageEXT;
 using gl::glNamedRenderbufferStorageMultisampleEXT;
 using gl::glNamedStringARB;
@@ -1372,6 +1385,7 @@ using gl::glReferencePlaneSGIX;
 using gl::glReleaseKeyedMutexWin32EXT;
 using gl::glRenderGpuMaskNV;
 using gl::glRenderbufferStorageEXT;
+using gl::glRenderbufferStorageMultisampleAdvancedAMD;
 using gl::glRenderbufferStorageMultisampleCoverageNV;
 using gl::glRenderbufferStorageMultisampleEXT;
 using gl::glReplacementCodePointerSUN;
@@ -1400,6 +1414,7 @@ using gl::glReplacementCodeusvSUN;
 using gl::glRequestResidentProgramsNV;
 using gl::glResetHistogram;
 using gl::glResetHistogramEXT;
+using gl::glResetMemoryObjectParameterNV;
 using gl::glResetMinmax;
 using gl::glResetMinmaxEXT;
 using gl::glResizeBuffersMESA;
@@ -1414,6 +1429,8 @@ using gl::glSampleMaskSGIS;
 using gl::glSamplePatternEXT;
 using gl::glSamplePatternSGIS;
 using gl::glScalexOES;
+using gl::glScissorExclusiveArrayvNV;
+using gl::glScissorExclusiveNV;
 using gl::glSecondaryColor3bEXT;
 using gl::glSecondaryColor3bvEXT;
 using gl::glSecondaryColor3dEXT;
@@ -1449,6 +1466,10 @@ using gl::glShaderOp1EXT;
 using gl::glShaderOp2EXT;
 using gl::glShaderOp3EXT;
 using gl::glShaderSourceARB;
+using gl::glShadingRateImageBarrierNV;
+using gl::glShadingRateImagePaletteNV;
+using gl::glShadingRateSampleOrderCustomNV;
+using gl::glShadingRateSampleOrderNV;
 using gl::glSharpenTexFuncSGIS;
 using gl::glSignalSemaphoreEXT;
 using gl::glSignalVkFenceNV;
@@ -1496,6 +1517,7 @@ using gl::glTessellationModeAMD;
 using gl::glTestFenceAPPLE;
 using gl::glTestFenceNV;
 using gl::glTestObjectAPPLE;
+using gl::glTexAttachMemoryNV;
 using gl::glTexBufferARB;
 using gl::glTexBufferEXT;
 using gl::glTexBumpParameterfvATI;
@@ -1567,6 +1589,7 @@ using gl::glTexSubImage1DEXT;
 using gl::glTexSubImage2DEXT;
 using gl::glTexSubImage3DEXT;
 using gl::glTexSubImage4DSGIS;
+using gl::glTextureAttachMemoryNV;
 using gl::glTextureBarrier;
 using gl::glTextureBarrierNV;
 using gl::glTextureBuffer;
@@ -1712,6 +1735,7 @@ using gl::glVDPAUIsSurfaceNV;
 using gl::glVDPAUMapSurfacesNV;
 using gl::glVDPAURegisterOutputSurfaceNV;
 using gl::glVDPAURegisterVideoSurfaceNV;
+using gl::glVDPAURegisterVideoSurfaceWithPictureStructureNV;
 using gl::glVDPAUSurfaceAccessNV;
 using gl::glVDPAUUnmapSurfacesNV;
 using gl::glVDPAUUnregisterSurfaceNV;
